<?php

namespace Drupal\commerce_stock_notifications;

use Drupal\datetime\Plugin\Field\FieldType\DateTimeItemInterface;
use Drupal\commerce_product\Entity\ProductVariation;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityListBuilder;

/**
 * Defines a class to build a listing of Stock notification entities.
 *
 * @ingroup commerce_stock_notifications
 */
class StockNotificationListBuilder extends EntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['id'] = $this->t('ID');
    $header['email'] = $this->t('User E-Mail');
    $header['product'] = $this->t('Product');
    $header['submit'] = $this->t('Submitted on');
    $header['sent'] = $this->t('Sent on');
    $header['action'] = $this->t('Unsubscribe link');
    return $header;
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    try {
      /** @var \Drupal\commerce_stock_notifications\Entity\StockNotificationInterface $notification */
      $notification = $entity;

      $row['id'] = $notification->id();
      $row['email'] = $notification->getEmail();
      $row['product'] = ProductVariation::load($notification->get('product_id')->getString())->getTitle();
      $row['submit'] = date(DateTimeItemInterface::DATETIME_STORAGE_FORMAT, $notification->get('submit_time')->getString());
      if (!empty($notification->get('sent_time')->getString())) {
        $row['sent'] = date(DateTimeItemInterface::DATETIME_STORAGE_FORMAT, $notification->get('sent_time')
          ->getString());
      }
      else {
        $row['sent'] = $this->t('Not sent yet');
      }
      $row['action'] = \Drupal::request()->getSchemeAndHttpHost() .
        '/user/' . $notification->get('user_id')->getString() .
        '/stock-notifications/unsubscribe/' . $notification->id();
      return $row;
    }
    catch (\Error $e) {
      return [];
    }
  }

}
